ChannelMap

Struct ChannelMap 

pub struct ChannelMap { /* private fields */ }
An ordered sequence of channels.

Implementations

Source

impl ChannelMap

pub fn new() -> Self

Creates a new sequence of channels.

pub fn add_channel(&mut self, ch: ChannelType)

Adds a single channel to the map.

pub fn add_channels(&mut self, chs: &[ChannelType])

Adds several channels to the map in order of occurrence.

pub fn len(&self) -> usize

Returns the total number of channels of the map.

pub fn is_empty(&self) -> bool

Tells if the channel map is empty.

pub fn get_channel(&self, idx: usize) -> ChannelType

Gets the channel type for a requested index.

pub fn find_channel_id(&self, t: ChannelType) -> Option<u8>

Tries to find the position of a determined type of channel in the map.

pub fn default_map(count: usize) -> Self

Creates a default channel map.

Depending on the count value, the channel map is defined differently.

When count is 1 –> the channel map is composed by a single centered channel.

When count is 2 –> the channel map is composed by a right and a left channel respectively.

For other count values, no other implementations are given for now.