Module frame

Module frame 

Packets and decoded frames functionality.

Structs

AudioInfo
Audio stream information contained in a frame.
Frame
Decoded frame information.
VideoInfo
Video stream information.

Enums

FrameError
Frame errors.
FrameType
A list of recognized frame types.
MediaKind
A list of possible stream information types.

Traits

FrameBuffer
A series of methods to interact with the planes of frame.
FrameBufferConv
A series of methods to get mutable and immutable slices of datatype T from frame planes.
FrameBufferCopy
A series of methods to copy the content of a frame from or to a buffer.

Type Aliases

ArcFrame
A specialized type for reference-counted Frame